__all__ = (
    "__title__", "__summary__", "__uri__", "__version__", "__author__",
    "__email__", "__license__", "__copyright__",
)

__title__ = "zk-rn-lib-maker"
__summary__ = "create react-native lib for zhike"
__uri__ = "https://gitee.com/smartstudy/zk_rn_lib_maker.git"

__version__ = "1.0.0"

__author__ = "JeffreyCao"
__email__ = "je255reycao@outlook.com"

__license__ = "MIT Licence"
__copyright__ = "Copyright 2019 JeffreyCao"



#!/usr/bin/env python3
# 编写自己的脚本
# react-native-create-library --module-prefix "@zhike-private/rn" --package-identifier "com.smartstudy.protocalview" protocal-view

import sys
import re
import os
lib_name_re = re.compile(r'^[a-z][a-z0-9|\-]*[a-z|0-9]$')


def check_lib_name(lib_name):
    return lib_name_re.match(lib_name)


def print_lib_name():
    print('''组件名称要求:
        1. 非数字开头
        2. 小写字母或数字
        3. 以中横线作为单词间的分割。
    ''')


def print_using():
    print(f'''
    {__file__} lib-name
    lib-name:
    1. 非数字开头
    2. 小写字母或数字
    3. 以中横线(-)作为单词间的分割。

    例如:
    "{__file__} protocal-view"
    将会在当前目录下创建名为protocal-view的lib库工程.
    ''')


def main():
    arg_count = len(sys.argv)
    if arg_count < 2:
        print_using()
        return

    lib_name = sys.argv[1]
    if not check_lib_name(lib_name):
        print_lib_name()
    android_id = f"com.smartstudy.{lib_name.replace('-','')}"
    cmd = f'react-native-create-library {lib_name} '\
        '--module-prefix "@zhike-private/rn" '\
        f'--package-identifier "{android_id}" '\
        f'&& rm -rf ./{lib_name}/windows'

    os.system(cmd)


if __name__ == "__main__":
    main()



#!/usr/bin/env python3
# -*- coding:utf-8 -*-

#############################################
# File Name: setup.py
# Author: JeffreyCao
# Mail: jeffreycao1024@gmail.com
# Created Time:  2019-11-16 21:48:34
# https://packaging.python.org/guides/distributing-packages-using-setuptools/#package-data
#############################################

# from setuptools import setup, find_packages  # 这个包没有的可以pip一下
import setuptools

setuptools.setup(
    name="zk_rn_lib_maker",
    version="1.0.0",
    keywords=("pip", "zk_rn_lib_maker"),
    description="Tool to create react-native lib for zhike",
    long_description="Tool to create react-native lib for zhike",
    license="MIT Licence",

    url="https://gitee.com/smartstudy/zk_rn_lib_maker.git",
    author="JeffreyCao",
    author_email="jeffreycao1024@gmail.com",

    packages=setuptools.find_packages(),
    include_package_data=True,
    package_data={
        'zk_logo_maker': ['ZhenyanGB.ttf'],
    },
    platforms="any",
    # install_requires=["Pillow"],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
    entry_points={
        'console_scripts': [
            'zk-rn-lib-maker = zk_rn_lib_maker.__main__:main'
        ]
    }
)
